Improve this doc

# $compile

Here are the list of errors in the $compile namespace.

Name | Description
--- | ---
ctreq | Missing Required Controller
iscp | Invalid Isolate Scope Definition
multidir | Multiple Directive Resource Contention
nodomevents | Interpolated Event Attributes
nonassign | Non-Assignable Expression
selmulti | Binding to Multiple Attribute
tpload | Error Loading Template
tplrt | Invalid Template Root
uterdir | Unterminated Directive